@@ -1,5 +1,5 @@
 #!/usr/bin/env -S perl -Ilib
-use Test::More tests => 1;
+use Test::More tests => 2;
 use POSIX 'dup2';
 dup2 fileno(STDERR), fileno(STDOUT);
 use strict;
@@ -15,10 +15,10 @@ BEGIN {
   package Foo;
   use base 'sealed';
   use sealed 'deparse';
+  sub foo { shift }
   my $n;
-  sub foo {shift}
-  sub _foo :Sealed { my Foo $x = shift; $n++ ? $x->bar : $x->main::recursive }
-  sub bar  { shift . "->::Foo::bar" }
+  sub _foo :Sealed { my Foo $x = shift; $n++ ? $x->bar : $x->main::reentrant }
+  sub bar  { 1 }
 }
 sub func   {Foo::foo($x)}
 BEGIN{@::ISA=('Foo')}
@@ -41,9 +41,9 @@ sub also_sealed :Sealed {
     $a->bar();
 }
 
-sub recursive :Sealed { my main $b = shift; local our @Q=1; my $c = $b->_foo }
+sub reentrant :Sealed { my main $b = shift; local our @Q=1; my $c = $b->_foo }
 
-print $y->main::recursive(), "\n";
+ok($y->main::reentrant()==1);
 
 my %tests = (
     func => \&func,
@@ -52,5 +52,7 @@ my %tests = (
     class => \&class,
     anon => \&anon,
 );
-eval 'cmpthese 20_000_000, \%tests';
+
+cmpthese 20_000_000, \%tests;
+
 ok(1);
